<?php
header('Content-Type: application/json');
session_start();
require_once 'db.php';

$action = $_REQUEST['action'] ?? '';

if ($action === 'createCall') {
    $user_id = $_REQUEST['user_id'] ?? '';
    $phone_number = $_REQUEST['phone_number'] ?? '';
    if (!$user_id) {
        echo json_encode(['success' => false, 'message' => 'Missing user_id']);
        exit;
    }
    try {
        $stmt = $pdo->prepare("INSERT INTO calls (user_id, status, phone_number) VALUES (?, 'queued', ?)");
        $stmt->execute([$user_id, $phone_number]);
        $cid = $pdo->lastInsertId();
        $stmt = $pdo->prepare("INSERT INTO call_history (call_id, action, details) VALUES (?, 'created', ?)");
        $stmt->execute([$cid, 'Call initiated by user']);
        echo json_encode(['success' => true, 'call_id' => $cid]);
    } catch (PDOException $e) {
        echo json_encode(['success' => false, 'message' => $e->getMessage()]);
    }
    exit;
}

if ($action === 'sendOffer') {
    $call_id = (int)($_REQUEST['call_id'] ?? 0);
    $offer = $_REQUEST['offer'] ?? '';
    if (!$call_id || !$offer) {
        echo json_encode(['success' => false, 'message' => 'Missing call_id or offer']);
        exit;
    }
    try {
        $stmt = $pdo->prepare("UPDATE calls SET offer = ?, status = 'offered' WHERE id = ?");
        $stmt->execute([$offer, $call_id]);
        $stmt = $pdo->prepare("INSERT INTO call_history (call_id, action, details) VALUES (?, 'offered', ?)");
        $stmt->execute([$call_id, 'User sent WebRTC offer']);
        echo json_encode(['success' => true]);
    } catch (PDOException $e) {
        echo json_encode(['success' => false, 'message' => $e->getMessage()]);
    }
    exit;
}

if ($action === 'sendAnswer') {
    $call_id = (int)($_REQUEST['call_id'] ?? 0);
    $answer = $_REQUEST['answer'] ?? '';
    if (!$call_id || !$answer) {
        echo json_encode(['success' => false, 'message' => 'Missing call_id or answer']);
        exit;
    }
    try {
        $admin_id = $_SESSION['admin_id'] ?? null;
        $stmt = $pdo->prepare("UPDATE calls SET answer = ?, status = 'accepted', admin_id = ? WHERE id = ?");
        $stmt->execute([$answer, $admin_id, $call_id]);
        $stmt = $pdo->prepare("INSERT INTO call_history (call_id, admin_id, action, details) VALUES (?, ?, 'accepted', ?)");
        $stmt->execute([$call_id, $admin_id, 'Admin accepted call']);
        echo json_encode(['success' => true]);
    } catch (PDOException $e) {
        echo json_encode(['success' => false, 'message' => $e->getMessage()]);
    }
    exit;
}

if ($action === 'sendIceCandidate') {
    $call_id = (int)($_REQUEST['call_id'] ?? 0);
    $role = $_REQUEST['role'] ?? '';
    $candidate = $_REQUEST['candidate'] ?? '';
    if (!$call_id || !$role || !$candidate) {
        echo json_encode(['success' => false, 'message' => 'Missing params']);
        exit;
    }
    $col = ($role === 'admin') ? 'ice_admin' : 'ice_user';
    try {
        $stmt = $pdo->prepare("SELECT $col FROM calls WHERE id = ?");
        $stmt->execute([$call_id]);
        $row = $stmt->fetch(PDO::FETCH_ASSOC);
        if (!$row) {
            echo json_encode(['success' => false, 'message' => 'Call not found']);
            exit;
        }
        $cur = $row[$col] ? json_decode($row[$col], true) : [];
        if (!is_array($cur)) {
            $cur = [];
        }
        $cur[] = $candidate;
        $stmt2 = $pdo->prepare("UPDATE calls SET $col = ? WHERE id = ?");
        $stmt2->execute([json_encode($cur), $call_id]);
        echo json_encode(['success' => true]);
    } catch (PDOException $e) {
        echo json_encode(['success' => false, 'message' => $e->getMessage()]);
    }
    exit;
}

if ($action === 'getCall') {
    $call_id = (int)($_REQUEST['call_id'] ?? 0);
    if (!$call_id) {
        echo json_encode(['success' => false, 'message' => 'Missing call_id']);
        exit;
    }
    try {
        $stmt = $pdo->prepare("SELECT * FROM calls WHERE id = ?");
        $stmt->execute([$call_id]);
        $call = $stmt->fetch(PDO::FETCH_ASSOC);
        if (!$call) {
            echo json_encode(['success' => false, 'message' => 'Call not found']);
        } else {
            echo json_encode(['success' => true, 'call' => [
                'id' => $call['id'],
                'user_id' => $call['user_id'],
                'admin_id' => $call['admin_id'],
                'status' => $call['status'],
                'offer' => $call['offer'],
                'answer' => $call['answer'],
                'ice_user' => $call['ice_user'] ? json_decode($call['ice_user'], true) : [],
                'ice_admin' => $call['ice_admin'] ? json_decode($call['ice_admin'], true) : [],
                'phone_number' => $call['phone_number'] ?: '',
                'created_at' => $call['created_at']
            ]]);
        }
    } catch (PDOException $e) {
        echo json_encode(['success' => false, 'message' => $e->getMessage()]);
    }
    exit;
}

if ($action === 'endCall') {
    $call_id = (int)($_REQUEST['call_id'] ?? 0);
    if (!$call_id) {
        echo json_encode(['success' => false, 'message' => 'Missing call_id']);
        exit;
    }
    try {
        $stmt = $pdo->prepare("UPDATE calls SET status = 'ended', admin_id = NULL, offer = NULL, answer = NULL, ice_user = NULL, ice_admin = NULL, ended_at = NOW() WHERE id = ?");
        $stmt->execute([$call_id]);
        $stmt = $pdo->prepare("INSERT INTO call_history (call_id, admin_id, action, details) VALUES (?, ?, 'ended', ?)");
        $stmt->execute([$call_id, $_SESSION['admin_id'] ?? null, 'Call ended by admin or user']);
        echo json_encode(['success' => true]);
    } catch (PDOException $e) {
        echo json_encode(['success' => false, 'message' => $e->getMessage()]);
    }
    exit;
}

if ($action === 'requeueCall') {
    $call_id = (int)($_REQUEST['call_id'] ?? 0);
    if (!$call_id) {
        echo json_encode(['success' => false, 'message' => 'Missing call_id']);
        exit;
    }
    try {
        $stmt = $pdo->prepare("UPDATE calls SET admin_id = NULL, offer = NULL, answer = NULL, ice_user = NULL, ice_admin = NULL, status = 'queued' WHERE id = ?");
        $stmt->execute([$call_id]);
        $stmt = $pdo->prepare("INSERT INTO call_history (call_id, admin_id, action, details) VALUES (?, ?, 'requeued', ?)");
        $stmt->execute([$call_id, $_SESSION['admin_id'] ?? null, 'Call requeued to another admin']);
        echo json_encode(['success' => true]);
    } catch (PDOException $e) {
        echo json_encode(['success' => false, 'message' => $e->getMessage()]);
    }
    exit;
}

if ($action === 'muteCall') {
    $call_id = (int)($_REQUEST['call_id'] ?? 0);
    $is_muted = $_REQUEST['is_muted'] ?? '0';
    if (!$call_id) {
        echo json_encode(['success' => false, 'message' => 'Missing call_id']);
        exit;
    }
    try {
        $action_type = $is_muted === '1' ? 'muted' : 'unmuted';
        $stmt = $pdo->prepare("INSERT INTO call_history (call_id, admin_id, action, details) VALUES (?, ?, ?, ?)");
        $details = $is_muted === '1' ? 'Admin muted the call' : 'Admin unmuted the call';
        $stmt->execute([$call_id, $_SESSION['admin_id'] ?? null, $action_type, $details]);
        echo json_encode(['success' => true]);
    } catch (PDOException $e) {
        echo json_encode(['success' => false, 'message' => $e->getMessage()]);
    }
    exit;
}

echo json_encode(['success' => false, 'message' => 'Unknown action']);
?>
